@@ -238,7 +238,7 @@ class ConfigInfoData(object):
         "nmr-data-nef-report": (["json"], "nmr-data-nef-report"),
         "nmr-data-str-report": (["json"], "nmr-data-str-report"),
         "nmr-restraints": (
-            ["any", "nmr-star", "amber", "amber-aux", "biosym", "cns", "cyana", "dynamo", "gromacs", "rosetta", "sybyl", "xplor", "xplor-nih", "pdb-mr", "mr"],
+            ["any", "nmr-star", "amber", "amber-aux", "biosym", "charmm", "cns", "cyana", "dynamo", "gromacs", "isd", "rosetta", "sybyl", "xplor", "xplor-nih", "pdb-mr", "mr"],
             "mr",
         ),
         "nmr-chemical-shifts": (["nmr-star", "pdbx", "any"], "cs"),
@@ -429,10 +429,12 @@ class ConfigInfoData(object):
         "amber": "amber",
         "amber-aux": "amber-aux",
         "biosym": "biosym",
+        "charmm": "charmm",
         "cns": "cns",
         "cyana": "cyana",
         "dynamo": "dynamo",
         "gromacs": "gromacs",
+        "isd": "isd",
         "rosetta": "rosetta",
         "sybyl": "sybyl",
         "xplor": "xplor",
@@ -495,7 +497,7 @@ class ConfigInfoData(object):
         "WWPDB_DEPLOY_NEXT_RU": "https://deposit.wwpdb.org/deposition",
         "WWPDB_DEPLOY_LEGACY_RU": "https://deposit-legacy.wwpdb.org/deposition",
         "WWPDB_DEPLOY_PRODUCTION_UCSD": "https://deposit-rcsb-west.wwpdb.org/deposition",
-        "WWPDB_DEPLOY_BETA_RU": "https://onedep-beta-dep-1.rcsb.rutgers.edu",
+        "WWPDB_DEPLOY_BETA_RU": "https://onedep-beta-dep-1.rcsb.rutgers.edu/deposition",
         "WWPDB_DEPLOY_PRODUCTION_PDBJ": "https://deposit-pdbj.wwpdb.org/deposition",
         "WWPDB_DEPLOY_PRODUCTION_PDBC": "https://deposit-pdbc.wwpdb.org/deposition",
         "PDBE_PROD": "https://deposit-pdbe.wwpdb.org/deposition",
@@ -505,7 +507,7 @@ class ConfigInfoData(object):
         "PDBE_VAL": "https://validate-pdbe.wwpdb.org/validservice",
         # 'PDBE_DEV': 'https://dev.pdbe.org/deposition',
         "WWPDB_DEPLOY_ALPHA_RU": "https://da-dep-alpha-0.rcsb.rutgers.edu/deposition",
-        "WWPDB_DEPLOY_TEST_RU": "https://wwpdb-deploy-test-1.wwpdb.org/deposition",
+        "WWPDB_DEPLOY_TEST_RU": "https://da-test-dep-1.rcsb.rutgers.edu/deposition",
         "WWPDB_DEPLOY_VALSRV2_RU": "https://validate-rcsb-east.wwpdb.org/validservice",
         "WWPDB_DEPLOY_VALSRV2_UCSD": "https://validate-rcsb-west.wwpdb.org/validservice",
     }
